@@ -6,18 +6,13 @@
 
 #pragma once
 
-#include "config-NetworkManagerQt.h"
-
 #include <unordered_map>
 
 #include <QDate>
+#include <QNetworkInformation>
 #include <QObject>
 #include <QTimer>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
-#include <QNetworkInformation>
-#elif HAVE_NetworkManagerQt
-#include <NetworkManagerQt/Manager>
-#endif
+
 #include <KPluginMetaData>
 
 #include "potdprovider.h"
@@ -33,19 +28,21 @@ public:
     PotdClient(const KPluginMetaData &metadata, const QVariantList &args, QObject *parent = nullptr);
 
     void updateSource(bool refresh = false);
-#if SUPPORT_METERED_DETECTION
     void setUpdateOverMeteredConnection(int value);
-#endif
 
     KPluginMetaData m_metadata;
-    PotdProviderData m_data;
     bool m_loading = false;
 
+    QUrl m_remoteUrl;
+    QUrl m_infoUrl;
+    QString m_localPath;
+    QString m_title;
+    QString m_author;
+
 Q_SIGNALS:
     /**
      * Emitted only when the image content has been updated
      */
-    void imageChanged();
     void loadingChanged();
     void localUrlChanged();
     void infoUrlChanged();
@@ -55,9 +52,9 @@ Q_SIGNALS:
     void done(PotdClient *client, bool success);
 
 private Q_SLOTS:
-    void slotFinished(PotdProvider *provider);
+    void slotFinished(PotdProvider *provider, const QImage &image);
     void slotError(PotdProvider *provider);
-    void slotCachingFinished(const QString &source, const PotdProviderData &data);
+    void slotCached(const QString &localPath);
 
 private:
     void setLoading(bool status);
@@ -69,10 +66,7 @@ private:
 
     QString m_identifier;
     QVariantList m_args;
-    bool m_imageChanged = false;
-#if SUPPORT_METERED_DETECTION
     int m_doesUpdateOverMeteredConnection = 0;
-#endif
 
     friend class PotdEngine;
 };
@@ -104,14 +98,11 @@ private Q_SLOTS:
     void forceUpdateSource();
     void slotDone(PotdClient *client, bool success);
     void slotPrepareForSleep(bool sleep);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
     void slotReachabilityChanged(QNetworkInformation::Reachability newReachability);
     void slotIsMeteredChanged(bool isMetered);
-#elif HAVE_NetworkManagerQt
-    void slotConnectivityChanged(NetworkManager::Connectivity connectivity);
-#endif
 
 private:
+    void loadNetworkInformation();
     void loadPluginMetaData();
 
     struct ClientPair {
